@@ -119,6 +119,12 @@ INVALIDPARAMETERVALUE_BACKUPNOTEXISTS = 'InvalidParameterValue.BackupNotExists'
 # 不是vpc网络下实例。
 INVALIDPARAMETERVALUE_BASENETWORKACCESSDENY = 'InvalidParameterValue.BaseNetWorkAccessDeny'
 
+# 业务校验不通过。
+INVALIDPARAMETERVALUE_CHECKNOTPASS = 'InvalidParameterValue.CheckNotPass'
+
+# 重命名，命名规则错误。
+INVALIDPARAMETERVALUE_INSTANCENAMERULEERROR = 'InvalidParameterValue.InstanceNameRuleError'
+
 # 请求购买的实例类型错误（TypeId 1:集群版；2:主从版,即原主从版)。
 INVALIDPARAMETERVALUE_INVALIDINSTANCETYPEID = 'InvalidParameterValue.InvalidInstanceTypeId'
 
@@ -128,6 +134,9 @@ INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 # 请求的容量不在售卖容量范围内。
 INVALIDPARAMETERVALUE_MEMSIZENOTINRANGE = 'InvalidParameterValue.MemSizeNotInRange'
 
+# 实例不能重复绑定。
+INVALIDPARAMETERVALUE_NOTREPEATBIND = 'InvalidParameterValue.NotRepeatBind'
+
 # 密码为空。
 INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'
 
@@ -143,6 +152,9 @@ INVALIDPARAMETERVALUE_PASSWORDRULEERROR = 'InvalidParameterValue.PasswordRuleErr
 # 请求容量偏小，不支持缩容。
 INVALIDPARAMETERVALUE_REDUCECAPACITYNOTALLOWED = 'InvalidParameterValue.ReduceCapacityNotAllowed'
 
+# 复制组不存在。
+INVALIDPARAMETERVALUE_REPLICATIONGROUPNOTEXISTS = 'InvalidParameterValue.ReplicationGroupNotExists'
+
 # 请求参数错误，安全组id错误。
 INVALIDPARAMETERVALUE_SECURITYGROUPIDSNOTEXISTS = 'InvalidParameterValue.SecurityGroupIdsNotExists'
 
@@ -158,6 +170,12 @@ INVALIDPARAMETERVALUE_UNVPCIDNOTEXISTS = 'InvalidParameterValue.UnVpcIdNotExists
 # weekday输入无效数据。
 INVALIDPARAMETERVALUE_WEEKDAYSISINVALID = 'InvalidParameterValue.WeekDaysIsInvalid'
 
+# 绑定超过上限。
+LIMITEXCEEDED_EXCEEDUPPERLIMIT = 'LimitExceeded.ExceedUpperLimit'
+
+# 绑定实例必须为空。
+LIMITEXCEEDED_INSTANCENOTEMPTY = 'LimitExceeded.InstanceNotEmpty'
+
 # 请求的容量不在售卖规格中（memSize应为1024的整数倍，单位：MB）。
 LIMITEXCEEDED_INVALIDMEMSIZE = 'LimitExceeded.InvalidMemSize'
 
@@ -173,6 +191,9 @@ LIMITEXCEEDED_PERIODEXCEEDMAXLIMIT = 'LimitExceeded.PeriodExceedMaxLimit'
 # 购买时长非法，时长最少1个月。
 LIMITEXCEEDED_PERIODLESSTHANMINLIMIT = 'LimitExceeded.PeriodLessThanMinLimit'
 
+# 复制组已锁定。
+LIMITEXCEEDED_REPLICATIONGROUPLOCKED = 'LimitExceeded.ReplicationGroupLocked'
+
 # 实例被其它流程锁住。
 RESOURCEINUSE_INSTANCEBEENLOCKED = 'ResourceInUse.InstanceBeenLocked'
 
@@ -251,6 +272,12 @@ UNAUTHORIZEDOPERATION_USERNOTINWHITELIST = 'UnauthorizedOperation.UserNotInWhite
 # redis 集群版不允许接入安全组。
 UNSUPPORTEDOPERATION_CLUSTERINSTANCEACCESSEDDENY = 'UnsupportedOperation.ClusterInstanceAccessedDeny'
 
+# 复制组巡检中。
+UNSUPPORTEDOPERATION_INSPECTION = 'UnsupportedOperation.Inspection'
+
+# 不支持当前操作。
+UNSUPPORTEDOPERATION_INSTANCENOTOPERATION = 'UnsupportedOperation.InstanceNotOperation'
+
 # 自动续费标识错误。
 UNSUPPORTEDOPERATION_ISAUTORENEWERROR = 'UnsupportedOperation.IsAutoRenewError'
 
